@@ -1,13 +1,11 @@
 import argparse
 
-from cpm.api.result import Result
-from cpm.api.result import OK
-from cpm.api.result import FAIL
+from cpm.api.result import Result, OK, FAIL
 from cpm.domain.cmake.cmakelists_builder import CMakeListsBuilder
 from cpm.domain.compilation_service import CompilationService
 from cpm.domain.project_commands import DockerImageNotFound
 from cpm.domain.project.project_descriptor_parser import NotACpmProject
-from cpm.domain.project.project_loader import ProjectLoader
+from cpm.domain.project.project_loader import ProjectLoader, InvalidTarget
 from cpm.domain.project_commands import ProjectCommands, BuildError
 
 
@@ -18,6 +16,8 @@ def build_project(compilation_service, target='default'):
         return Result(FAIL, f'error: not a cpm project')
     except BuildError:
         return Result(FAIL, f'error: compilation failed')
+    except InvalidTarget:
+        return Result(FAIL, f'error: unknown target {target}')
     except DockerImageNotFound as e:
         return Result(FAIL, f'error: docker image {e.image_name} not found for target {target}')
 
